@@ -121,7 +121,7 @@ Below is a description of the different resources and methods exposed by the API
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -137,14 +137,14 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_apigateway
-import aws_cdk.aws_iam
-import aws_cdk.aws_logs
-import constructs
+import aws_cdk.aws_apigateway as _aws_cdk_aws_apigateway_ceddda9d
+import aws_cdk.aws_iam as _aws_cdk_aws_iam_ceddda9d
+import aws_cdk.aws_logs as _aws_cdk_aws_logs_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class ApiGatewayToIot(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-apigateway-iot.ApiGatewayToIot",
 ):
@@ -154,14 +154,14 @@ class ApiGatewayToIot(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         iot_endpoint: builtins.str,
         api_gateway_create_api_key: typing.Optional[builtins.bool] = None,
-        api_gateway_execution_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
-        api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
-        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+        api_gateway_execution_role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
+        api_gateway_props: typing.Optional[typing.Union[_aws_cdk_aws_apigateway_ceddda9d.RestApiProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -177,18 +177,7 @@ class ApiGatewayToIot(
         :summary: Constructs a new instance of the ApiGatewayIot class.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                iot_endpoint: builtins.str,
-                api_gateway_create_api_key: typing.Optional[builtins.bool] = None,
-                api_gateway_execution_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
-                api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
-                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__2e924fb0cf81b109b48a204074c76b3f0589533998633acfa966ff106a85324c)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ApiGatewayToIotProps(
@@ -203,23 +192,25 @@ class ApiGatewayToIot(
 
     @builtins.property
     @jsii.member(jsii_name="apiGateway")
-    def api_gateway(self) -> aws_cdk.aws_apigateway.RestApi:
-        return typing.cast(aws_cdk.aws_apigateway.RestApi, jsii.get(self, "apiGateway"))
+    def api_gateway(self) -> _aws_cdk_aws_apigateway_ceddda9d.RestApi:
+        return typing.cast(_aws_cdk_aws_apigateway_ceddda9d.RestApi, jsii.get(self, "apiGateway"))
 
     @builtins.property
     @jsii.member(jsii_name="apiGatewayLogGroup")
-    def api_gateway_log_group(self) -> aws_cdk.aws_logs.LogGroup:
-        return typing.cast(aws_cdk.aws_logs.LogGroup, jsii.get(self, "apiGatewayLogGroup"))
+    def api_gateway_log_group(self) -> _aws_cdk_aws_logs_ceddda9d.LogGroup:
+        return typing.cast(_aws_cdk_aws_logs_ceddda9d.LogGroup, jsii.get(self, "apiGatewayLogGroup"))
 
     @builtins.property
     @jsii.member(jsii_name="apiGatewayRole")
-    def api_gateway_role(self) -> aws_cdk.aws_iam.IRole:
-        return typing.cast(aws_cdk.aws_iam.IRole, jsii.get(self, "apiGatewayRole"))
+    def api_gateway_role(self) -> _aws_cdk_aws_iam_ceddda9d.IRole:
+        return typing.cast(_aws_cdk_aws_iam_ceddda9d.IRole, jsii.get(self, "apiGatewayRole"))
 
     @builtins.property
     @jsii.member(jsii_name="apiGatewayCloudWatchRole")
-    def api_gateway_cloud_watch_role(self) -> typing.Optional[aws_cdk.aws_iam.Role]:
-        return typing.cast(typing.Optional[aws_cdk.aws_iam.Role], jsii.get(self, "apiGatewayCloudWatchRole"))
+    def api_gateway_cloud_watch_role(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_iam_ceddda9d.Role]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_iam_ceddda9d.Role], jsii.get(self, "apiGatewayCloudWatchRole"))
 
 
 @jsii.data_type(
@@ -239,9 +230,9 @@ class ApiGatewayToIotProps:
         *,
         iot_endpoint: builtins.str,
         api_gateway_create_api_key: typing.Optional[builtins.bool] = None,
-        api_gateway_execution_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
-        api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
-        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+        api_gateway_execution_role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
+        api_gateway_props: typing.Optional[typing.Union[_aws_cdk_aws_apigateway_ceddda9d.RestApiProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''The properties for the ApiGatewayIot class.
 
@@ -252,26 +243,17 @@ class ApiGatewayToIotProps:
         :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
         '''
         if isinstance(api_gateway_props, dict):
-            api_gateway_props = aws_cdk.aws_apigateway.RestApiProps(**api_gateway_props)
+            api_gateway_props = _aws_cdk_aws_apigateway_ceddda9d.RestApiProps(**api_gateway_props)
         if isinstance(log_group_props, dict):
-            log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
+            log_group_props = _aws_cdk_aws_logs_ceddda9d.LogGroupProps(**log_group_props)
         if __debug__:
-            def stub(
-                *,
-                iot_endpoint: builtins.str,
-                api_gateway_create_api_key: typing.Optional[builtins.bool] = None,
-                api_gateway_execution_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
-                api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
-                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__8700595a6a6afd7bc80184c79201387ce9c5cc241bfb91bc3cf126abc3e944c8)
             check_type(argname="argument iot_endpoint", value=iot_endpoint, expected_type=type_hints["iot_endpoint"])
             check_type(argname="argument api_gateway_create_api_key", value=api_gateway_create_api_key, expected_type=type_hints["api_gateway_create_api_key"])
             check_type(argname="argument api_gateway_execution_role", value=api_gateway_execution_role, expected_type=type_hints["api_gateway_execution_role"])
             check_type(argname="argument api_gateway_props", value=api_gateway_props, expected_type=type_hints["api_gateway_props"])
             check_type(argname="argument log_group_props", value=log_group_props, expected_type=type_hints["log_group_props"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "iot_endpoint": iot_endpoint,
         }
         if api_gateway_create_api_key is not None:
@@ -303,31 +285,37 @@ class ApiGatewayToIotProps:
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def api_gateway_execution_role(self) -> typing.Optional[aws_cdk.aws_iam.IRole]:
+    def api_gateway_execution_role(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole]:
         '''The IAM role that is used by API Gateway to publish messages to IoT topics and Thing shadows.
 
         :default: - An IAM role with iot:Publish access to all topics (topic/*) and iot:UpdateThingShadow access to all things (thing/*) is created.
         '''
         result = self._values.get("api_gateway_execution_role")
-        return typing.cast(typing.Optional[aws_cdk.aws_iam.IRole], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole], result)
 
     @builtins.property
-    def api_gateway_props(self) -> typing.Optional[aws_cdk.aws_apigateway.RestApiProps]:
+    def api_gateway_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_apigateway_ceddda9d.RestApiProps]:
         '''Optional user-provided props to override the default props for the API.
 
         :default: - Default props are used.
         '''
         result = self._values.get("api_gateway_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_apigateway.RestApiProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_apigateway_ceddda9d.RestApiProps], result)
 
     @builtins.property
-    def log_group_props(self) -> typing.Optional[aws_cdk.aws_logs.LogGroupProps]:
+    def log_group_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_logs_ceddda9d.LogGroupProps]:
         '''User provided props to override the default props for the CloudWatchLogs LogGroup.
 
         :default: - Default props are used
         '''
         result = self._values.get("log_group_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_logs.LogGroupProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_logs_ceddda9d.LogGroupProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -347,3 +335,27 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__2e924fb0cf81b109b48a204074c76b3f0589533998633acfa966ff106a85324c(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    iot_endpoint: builtins.str,
+    api_gateway_create_api_key: typing.Optional[builtins.bool] = None,
+    api_gateway_execution_role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
+    api_gateway_props: typing.Optional[typing.Union[_aws_cdk_aws_apigateway_ceddda9d.RestApiProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8700595a6a6afd7bc80184c79201387ce9c5cc241bfb91bc3cf126abc3e944c8(
+    *,
+    iot_endpoint: builtins.str,
+    api_gateway_create_api_key: typing.Optional[builtins.bool] = None,
+    api_gateway_execution_role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
+    api_gateway_props: typing.Optional[typing.Union[_aws_cdk_aws_apigateway_ceddda9d.RestApiProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
